@@ -3,7 +3,7 @@ package JavaScript::Minifier;
 use strict;
 use warnings;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -379,7 +379,7 @@ To minify a JavaScript file and have the output written directly to another file
 
 To minify a JavaScript string literal. Note that by omitting the outfile parameter a the minified code is returned as a string.
 
-  my minifiedJavaScript = minify(input => 'var x = 2;');
+  my $minifiedJavaScript = minify(input => 'var x = 2;');
 
 To include a copyright comment at the top of the minified code.
 
@@ -424,11 +424,13 @@ Zoffix Znet C<< <zoffix@cpan.org> >> L<https://metacpan.org/author/ZOFFIX>
 =head1 AUTHORS
 
 Peter Michaux, E<lt>petermichaux@gmail.comE<gt>
+
 Eric Herrera, E<lt>herrera@10east.comE<gt>
 
 =head1 CONTRIBUTORS
 
 Miller 'tmhall' Hall
+
 Вячеслав 'vti' Тихановский
 
 =head1 COPYRIGHT AND LICENSE
